@@ -5,7 +5,7 @@
     Author:        Jan Wielemaker and Peter Ludemann
     E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  2022-2024, SWI-Prolog Solutions b.v.
+    Copyright (c)  2022-2023, SWI-Prolog Solutions b.v.
     All rights reserved.
 
     Redistribution and use in source and binary forms, with or without
@@ -61,7 +61,7 @@ user:portray(MyBlob) :-
 %     run_tests([ cpp,
 %                 cpp_atommap,
 %                 cpp_map_str_str
-%	      ]).
+% 	      ]).
 
 test_cpp :-
     run_tests.
@@ -133,7 +133,7 @@ test(as_string, S == "hello(ä¸\u0096ç\u0095\u008Cå\u009B\u009B)") :-
 test(add_3, Result == 666) :-
     add(667, -1, Result).
 test(add_3, Result == 123) :-
-    add(100, 23, Result).
+    add(100.0, 23, Result).
 test(add_3_err, error(type_error(integer,0.1))) :-
     add(666, 0.1, _).
 
@@ -190,14 +190,6 @@ test(can_unify) :-
 test(can_unify, fail) :-
     can_unify(a(1), a(2)).
 
-test(can_unify_ffi, [true(X\==Y)]) :-
-    can_unify_ffi(f(X), f(Y)).
-test(can_unify_ffi) :-
-    can_unify_ffi(a(X), a(1)),
-    assertion(var(X)).
-test(can_unify_ffi, fail) :-
-    can_unify_ffi(a(1), a(2)).
-
 test(call_chars, Out=="1") :-
     with_output_to(string(Out), call_chars("X=1, write(X)")).
 test(call_chars, Out=="1") :-
@@ -632,8 +624,6 @@ test(name_to_terms, fail) :-
     name_to_terms("foo", _, _).
 test(name_to_terms, fail) :-
     name_to_terms("two", _, "deux").
-test(name_to_terms, error(type_error('atom or string',A))) :-
-     name_to_terms(A, 1, 2).
 
 test(name_to_terms2, [T1,T2] = [1,"eins"]) :-
     name_to_terms2("one", T1, T2).
@@ -813,28 +803,17 @@ test(blob) :-
     assertion(blob(Blob, my_blob)),
     close_my_blob(Blob).
 test(blob, error(my_blob_open_error(_),_)) :-
-    create_my_blob('-FAIL_open-', _).
+    create_my_blob('FAIL', _).
 test(blob, error(my_blob_close_error(Blob))) :-
-    create_my_blob('-FAIL_close-', Blob),
+    create_my_blob('FAIL_close', Blob),
     assertion(blob(Blob, my_blob)),
     close_my_blob(Blob).
-test(blob) :-
-    create_my_blob('foo', A),
-    with_output_to(string(Astr), write(current_output, A)),
-    assertion(string_concat("<my_blob>(", _, Astr)), % The pointer part is implementation-defined
-    free_blob(A),
-    with_output_to(string(Astr_freed), write(current_output, A)),
-    nil_repr(Nil),
-    format(string(Rstr), ">(~w)", [Nil]),
-    % The name part implementation-defined (e.g., mangled type name)
-    assertion(string_concat("<", _, Astr_freed)),
-    assertion(string_concat(_, Rstr, Astr_freed)).
 
 % The following attempts to test the handling of close errors in the
 % "release" callback, which calls ~MyBlob. It doesn't throw an error
 % (because it can't) but does output an error message.
 % You can run this test by hand:
-%    ?- create_fail_close_blob.
+%    ?- create_fail_blob.
 %    ?- force_gc.
 % and that should print:
 %    Close MyBlob failed: FAIL_close
@@ -842,25 +821,11 @@ test(blob, [blocked(cant_throw_error),
             error(e),
             setup(force_gc(GC_thread)),
             cleanup(restore_gc(GC_thread))]) :-
-    create_fail_close_blob,
+    create_fail_blob,
     garbage_collect,
     garbage_collect_atoms.
-test(blob, blocked(calls_PL_system_error)) :-
-    create_my_blob('-FAIL_connection-', _Blob).
-test(blob, error(my_blob_open_error(_))) :-
-    create_my_blob('-FAIL_open-', _Blob).
-test(blob, error(my_blob_fail_new(_))) :-
-    create_my_blob('-FAIL_new-', _Blob).
-test(blob, fail) :-
-    create_my_blob('-FAIL_compare-1', Blob1),
-    create_my_blob('-Fail_compare-2', Blob2),
-    Blob1 = Blob2.
-test(blob, error(my_blob_write_error(_))) :-
-    create_my_blob('-FAIL_write-', Blob),
-    with_output_to(string(_), write(current_output, Blob)).
-
-create_fail_close_blob :-
-    create_my_blob('-FAIL_close-', Blob),
+create_fail_blob :-
+    create_my_blob('FAIL_close', Blob),
     assertion(blob(Blob, my_blob)).
 
 test(blob, cleanup(close_my_blob(A))) :-
@@ -921,87 +886,6 @@ test(blob_portray, S == "MyBlob(closed)") :-
     close_my_blob(B),
     with_output_to(string(S), print(B)).
 
-test(nchars_flags, F-S == 0x43f-"xinteger,all") :-
-    nchars_flags([xinteger,all,atomic,number], F),
-    nchars_flags_string(F, S).
-test(nchars_flags, F-S == 0x37-"all") :-
-    nchars_flags([all,atomic,number], F),
-    nchars_flags_string(F, S).
-test(nchars_flags, F-S == 0x7ff-"xinteger,all,variable,write,write_canonical,writeq") :-
-    nchars_flags([atom,string,integer,list,rational,float,variable,number,atomic,write,write_canonical,writeq,all,xinteger], F),
-    nchars_flags_string(F, S).
-test(nchars_flags, F-S == 0x37-"all") :-
-    nchars_flags([atomic,list], F),
-    nchars_flags_string(F, S).
-test(nchars_flags, F-S == 0x33-"atomic") :-
-    nchars_flags([number,atom,string], F),
-    nchars_flags_string(F, S).
-
-test(nchars, S-FS-FS2 == "123"-"atomic"-"atomic") :-
-    nchars_flags([atomic], F),
-    nchars_flags_string(F, FS),
-    get_nchars_string(123, F, S, FS2).
-test(nchars, S-F == "123"-"atomic") :-
-    get_nchars_string(123, [atomic], S, F).
-test(nchars, error(type_error(atomic,f(a)))) :-
-    get_nchars_string(f(a), [atomic], _, _).
-test(nchars, S-F == "+(a,b)"-"all,write_canonical") :-
-    get_nchars_string(a+b, [write_canonical,all], S, F).
-
-% The flags to PlTerm::as_string are [all,writeq].
-% TODO: try more flag combinations
-
-test(nchars, [S-F == "a b"-"all,writeq"]) :-
-    get_nchars_string('a b', [all,writeq], S, F).
-test(nchars, [S-F == "a b"-"all,writeq"]) :-
-    get_nchars_string("a b", [all,writeq], S, F).
-test(nchars, [S-F == "'a b'"-"writeq"]) :-
-    get_nchars_string('a b', [writeq], S, F).
-test(nchars, [S-F == "\"a b\""-"writeq"]) :-
-    get_nchars_string("a b", [writeq], S, F).
-test(nchars, S-F == "f('a b')"-"all,writeq") :-
-    get_nchars_string(f('a b'), [all,writeq], S, F).
-test(nchars, S-F == "f(\"a b\")"-"all,writeq") :-
-    get_nchars_string(f("a b"), [all,writeq], S, F).
-test(nchars, S-F == "f(A,_,b,A)"-"writeq") :-
-    get_nchars_string(f(X,_,b,X), [writeq], S, F).
-
-test(nchars, S-F == "an atom"-"atom") :-
-    get_nchars_string('an atom', [atom], S, F).
-test(nchars, S-F == "a string"-"string") :-
-    get_nchars_string("a string", [string], S, F).
-test(nchars, S-F == "abc"-"list") :-
-    get_nchars_string([a,b,c], [list], S, F).
-test(nchars, S-F == "abcd"-"list") :-
-    get_nchars_string([0'a,0'b,0'c,0'd], [list], S, F).
-test(nchars, S-F == "10r3"-"rational") :-
-    get_nchars_string(20r6, [rational], S, F).
-test(nchars, S-F == "ar3"-"xinteger,rational") :-
-    get_nchars_string(20r6, [xinteger,rational], S, F).
-test(nchars, S-F == "14"-"xinteger,rational") :-
-    get_nchars_string(20, [xinteger,rational], S, F).
-test(nchars, S-F == "14"-"xinteger") :-
-    get_nchars_string(20, [xinteger], S, F).
-test(nchars, S-F == "0.25"-"xinteger,float") :-
-    get_nchars_string(0.25, [xinteger,float], S, F).
-
-% TODO: the type_error always shows atom - but making it more accurate
-%       would be more work than it's worth.
-test(nchars, error(type_error(atom,0.25))) :-
-    get_nchars_string(0.25, [xinteger], _S, _F).
-
-test(lookup_unify, N == 1) :-
-    lookup_unify(item(one, N)).
-test(lookup_unify, S == three) :-
-    lookup_unify(item(S, 3)).
-test(lookup_unify, fail) :-
-    lookup_unify(xxx).
-
-test(#, S == "abc") :-
-    #(abc, S).
-test(#, S == "foo(abc)") :-
-    #(foo(abc), S).
-
 compare_write_form(Compare, A, B) :-
     with_output_to(string(Astr), write(A)),
     with_output_to(string(Bstr), write(B)),
@@ -1137,46 +1021,10 @@ test(map, KVs = ["ab"-"two","ac"-"three"]) :-
     maplist(insert_or_assign_map_str_str(Map), ["ab","ac","d"], ["two","three","four"]),
     findall(K-V, enum_map_str_str(Map, "a", K, V), KVs).
 
-test(map) :-
+test(map, [blocked(crash),K2-V2 == "ab"-"two"]) :-
     create_map_str_str(Map),
     maplist(insert_or_assign_map_str_str(Map), ["ab","ac","d"], ["two","three","four"]),
-    enum_map_str_str(Map, "", K, V),
-    !, % cut after PL_FIRST_CALL
-    assertion(K == "ab"),
-    assertion(V == "two"),
-    enum_map_str_str(Map, "", K, V). % verify lookup with ground args, no choicepoint
-test(map, [nondet, K-V == "ab"-"two"]) :-
-    create_map_str_str(Map),
-    maplist(insert_or_assign_map_str_str(Map), ["ab","ac","d"], ["two","three","four"]),
-    enum_map_str_str(Map, "", K, V),
-    enum_map_str_str(Map, "", K, V). % verify lookup with ground args, no choicepoint
-test(map, K-V == "ac"-"three") :-
-    create_map_str_str(Map),
-    maplist(insert_or_assign_map_str_str(Map), ["ab","ac","d"], ["two","three","four"]),
-    enum_map_str_str(Map, "", K, V),
-    K \= "ab",
-    !, % cut after PL_REDO
-    assertion(K == "ac"),
-    assertion(V == "three"),
-    enum_map_str_str(Map, "", K, V). % verify lookup with ground args, no choicepoint
-test(map) :-
-    create_map_str_str(Map),
-    maplist(insert_or_assign_map_str_str(Map), ["ab","ac","d"], ["two","three","four"]),
-    enum_map_str_str(Map, "", K, V),
-    K \= "ab",
-    K \= "ac",
-    !, % cut after deterministic return
-    assertion(K == "d"),
-    assertion(V == "four"),
-    enum_map_str_str(Map, "", K, V). % verify lookup with ground args, no choicepoint
-test(map, Ks == ["ab", "x"]) :-
-    create_map_str_str(Map),
-    maplist(insert_or_assign_map_str_str(Map), ["ab","ac","d","x"], ["two","three","four","two"]),
-    findall(K, enum_map_str_str(Map, "", K, "two"), Ks).
-test(map, Ks == ["ab"]) :-
-    create_map_str_str(Map),
-    maplist(insert_or_assign_map_str_str(Map), ["ab","ac","d","x"], ["two","three","four","two"]),
-    findall(K, enum_map_str_str(Map, "a", K, "two"), Ks).
+    enum_map_str_str(Map, "", K2, V2), !.
 
 :- end_tests(cpp_map_str_str).
 
