@@ -44,10 +44,10 @@
             manual_object/5,            % ?Obj, ?Summary, ?File, ?Class, ?Offset
             doc_object_identifier/2     % +Obj, -Name
           ]).
+:- use_module(library(debug),[debug/3]).
 :- autoload(doc_util,[atom_to_object/2,normalise_white_space/3]).
 :- autoload(library(apply),[maplist/2]).
 :- autoload(library(assoc),[empty_assoc/1,get_assoc/3,put_assoc/4]).
-:- autoload(library(debug),[debug/3]).
 :- autoload(library(error),[type_error/2]).
 :- autoload(library(filesex),[directory_file_path/3]).
 :- autoload(library(lists),[member/2,reverse/2,append/3]).
@@ -336,7 +336,8 @@ index_man_file(Class, Symbolic, File) :-
 %   the open attributes. Parser is the parser objects.
 
 index_on_begin(dt, Attributes, Parser) :-
-    memberchk(class=pubdef, Attributes),
+    memberchk(class=Def, Attributes),
+    public_def(Def),
     get_sgml_parser(Parser, charpos(Offset)),
     get_sgml_parser(Parser, file(File)),
     sgml_parse(Parser,
@@ -427,6 +428,9 @@ section_id(_Attributes, Title, File, ID) :-
     atom_concat('sec:', ID0, ID),
     print_message(warning, pldoc(no_section_id(File, Title))).
 
+public_def(pubdef).
+public_def(multidef).
+
 %!  dom_section(+HeaderDOM, -NR, -Title) is semidet.
 %
 %   NR is the section number (e.g. 1.1, 1.23) and Title is the title
